close all;
% clear all;
% clc;
import MatlabToTikZ.*;

% CreateContinuousTimeSignals;

% load the parameters
N		= 101;							% num. of measurements
Delta	= n / (N-1);					% discretization time in number of "continuous time" samples
kk		= [round(1:Delta:n-1), n]';		% sampling indexes wrt the "continuous time" samples
discretization_period	= t(kk(2))-t(kk(1));	% Delta but in time in \Reals
sigma2	= 0.001;						% measurement noise

% generate the measurement process
clear y;
for k_index = 1:N;
	y(k_index, 1) = y_continuous(kk(k_index)) + sqrt(sigma2) * randn(1);
end;%
VisualizeMeasurements;

ComputeDiscreteTimeSignals;

% estimate the quantities
gamma	= 1000;
alpha	= 0.5;
F		= eye(N);
F(2:N,1:N-1) = F(2:N,1:N-1) - eye(N-1);
D		= (1 / (alpha - alpha^2)) * eye(N);
for k = 1:N;
	D(k,k) = D(k,k) / (alpha^(k-1)); 
end;%
D(N,N) = D(N,N) * (1-alpha);
ghatML	= inv( U_discrete' * U_discrete ) * U_discrete' * y;
ghatRLS	= inv( U_discrete' * U_discrete + gamma * F * inv(D) * F' ) * U_discrete' * y;

% plot the estimates
figure(6)
hold on;
% stairs(t(kk), ghatRLS, 'b');
stairs(t(kk), ghatML, 'r');
plot(t,g_continuous, 'k');
hold off
legend('ML', 'RLS', 'original');

% export the results
MatlabToTikZ.ExportLineplot(											...
	sprintf('../../Datasets/SS/estimates_N%d_gamma%.4f.txt', N, gamma),	...
	[ t(kk), ghatML, ghatRLS],											...
	[ {'t'}, {'ghat_ML'}, {'ghat_RLS'} ]								);



