close all;
% clear all;
% clc;
import MatlabToTikZ.*;

% CreateContinuousTimeSignals;

% load the parameters
N		= 1001;							% num. of measurements
Delta	= n / (N-1);					% discretization time in number of "continuous time" samples
kk		= [round(1:Delta:n-1), n]';		% sampling indexes wrt the "continuous time" samples
discretization_period	= t(kk(2))-t(kk(1));	% Delta but in time in \Reals
sigma2	= 0.001;						% measurement noise

% generate the measurement process
clear y;
for k_index = 1:numel(kk);
	y(k_index, 1) = y_continuous(kk(k_index)) + sqrt(sigma2) * randn(1);
end;%
VisualizeMeasurements;

ComputeDiscreteTimeSignals;

% estimate the quantities
gamma	= 1.9;
F		= eye(N);
F(2:N,1:N-1) = F(2:N,1:N-1) - eye(N-1);
uhatML	= inv( G_discrete ) * y;
uhatRLS	= inv( G_discrete' * G_discrete + gamma * F' * F ) * G_discrete' * y;

% plot the estimates
figure(4)
stairs(t(kk), uhatRLS, 'b');
hold on;
% stairs(t(kk), uhatML, 'r');
plot(t,u_continuous, 'k');
hold off
legend('ML', 'RLS', 'original');

% export the results
MatlabToTikZ.ExportLineplot(											...
	sprintf('../Datasets/Hunt/estimates_N%d_gamma%.4f.txt', N, gamma),	...
	[ t(kk), uhatML, uhatRLS],											...
	[ {'t'}, {'uhat_ML'}, {'uhat_RLS'} ]								);



